@@ -206,7 +206,9 @@ class TestScheduler:
         task_type = TEMPLATES["test-git"]["type"]
         # Create tasks with and without priorities
         tasks = tasks_from_template(
-            TEMPLATES["test-git"], t, num_priorities=NUM_PRIORITY_TASKS,
+            TEMPLATES["test-git"],
+            t,
+            num_priorities=NUM_PRIORITY_TASKS,
         )
 
         count_priority = 0
@@ -261,13 +263,22 @@ class TestScheduler:
         num_tasks = 100
         # Create tasks with and without priorities
         tasks0 = tasks_with_priority_from_template(
-            TEMPLATES["test-git"], t, num_tasks, "high",
+            TEMPLATES["test-git"],
+            t,
+            num_tasks,
+            "high",
         )
         tasks1 = tasks_with_priority_from_template(
-            TEMPLATES["test-hg"], t, num_tasks, "low",
+            TEMPLATES["test-hg"],
+            t,
+            num_tasks,
+            "low",
         )
         tasks2 = tasks_with_priority_from_template(
-            TEMPLATES["test-hg"], t, num_tasks, "normal",
+            TEMPLATES["test-hg"],
+            t,
+            num_tasks,
+            "normal",
         )
         tasks = tasks0 + tasks1 + tasks2
 
@@ -319,7 +330,7 @@ class TestScheduler:
         self, task: Dict[str, Any], after: datetime.datetime, before: datetime.datetime
     ) -> None:
         """Ensure filtered tasks have the right expected properties
-           (within the range, recurring disabled, etc..)
+        (within the range, recurring disabled, etc..)
 
         """
         started = task["started"]
@@ -331,9 +342,7 @@ class TestScheduler:
             assert task["task_status"] in ["disabled"]
 
     def test_filter_task_to_archive(self, swh_scheduler):
-        """Filtering only list disabled recurring or completed oneshot tasks
-
-        """
+        """Filtering only list disabled recurring or completed oneshot tasks"""
         self._create_task_types(swh_scheduler)
         _time = utcnow()
         recurring = tasks_from_template(TEMPLATES["test-git"], _time, 12)
@@ -662,6 +671,27 @@ class TestScheduler:
 
         assert swh_scheduler.get_listers() == db_listers
 
+    def test_get_listers_by_id(self, swh_scheduler):
+        assert swh_scheduler.get_listers_by_id([str(uuid.uuid4())]) == []
+
+        db_listers = []
+        for lister_args in LISTERS:
+            db_listers.append(swh_scheduler.get_or_create_lister(**lister_args))
+
+        id0 = db_listers[0].id
+        id1 = db_listers[1].id
+
+        assert swh_scheduler.get_listers_by_id([id0]) == [db_listers[0]]
+        assert swh_scheduler.get_listers_by_id([id1]) == [db_listers[1]]
+        assert swh_scheduler.get_listers_by_id([id0, id1]) == [
+            db_listers[0],
+            db_listers[1],
+        ]
+
+        assert swh_scheduler.get_listers_by_id([id0, str(uuid.uuid4())]) == [
+            db_listers[0]
+        ]
+
     def test_update_lister(self, swh_scheduler, stored_lister):
         lister = attr.evolve(stored_lister, current_state={"updated": "now"})
 
@@ -871,7 +901,9 @@ class TestScheduler:
         return visit_type, origins, expected
 
     def test_grab_next_visits_oldest_scheduled_first(
-        self, swh_scheduler, listed_origins_by_type,
+        self,
+        swh_scheduler,
+        listed_origins_by_type,
     ):
         visit_type, origins, expected = self._prepare_oldest_scheduled_first_origins(
             swh_scheduler, listed_origins_by_type
@@ -886,7 +918,11 @@ class TestScheduler:
     @pytest.mark.parametrize("which_cooldown", ("scheduled", "failed", "not_found"))
     @pytest.mark.parametrize("cooldown", (7, 15))
     def test_grab_next_visits_cooldowns(
-        self, swh_scheduler, listed_origins_by_type, which_cooldown, cooldown,
+        self,
+        swh_scheduler,
+        listed_origins_by_type,
+        which_cooldown,
+        cooldown,
     ):
         visit_type, origins, expected = self._prepare_oldest_scheduled_first_origins(
             swh_scheduler, listed_origins_by_type
@@ -953,7 +989,9 @@ class TestScheduler:
         ), "grab_next_visits didn't reschedule visits after the configured cooldown"
 
     def test_grab_next_visits_tablesample(
-        self, swh_scheduler, listed_origins_by_type,
+        self,
+        swh_scheduler,
+        listed_origins_by_type,
     ):
         visit_type, origins, expected = self._prepare_oldest_scheduled_first_origins(
             swh_scheduler, listed_origins_by_type
@@ -969,7 +1007,9 @@ class TestScheduler:
         assert ret is not None
 
     def test_grab_next_visits_never_visited_oldest_update_first(
-        self, swh_scheduler, listed_origins_by_type,
+        self,
+        swh_scheduler,
+        listed_origins_by_type,
     ):
         visit_type, origins = self._grab_next_visits_setup(
             swh_scheduler, listed_origins_by_type
@@ -995,7 +1035,9 @@ class TestScheduler:
         )
 
     def test_grab_next_visits_already_visited_order_by_lag(
-        self, swh_scheduler, listed_origins_by_type,
+        self,
+        swh_scheduler,
+        listed_origins_by_type,
     ):
         visit_type, origins = self._grab_next_visits_setup(
             swh_scheduler, listed_origins_by_type
@@ -1060,9 +1102,7 @@ class TestScheduler:
     def test_grab_next_visits_no_last_update_nor_visit_stats(
         self, swh_scheduler, listed_origins_by_type
     ):
-        """grab_next_visits should retrieve tasks without last update (nor visit stats)
-
-        """
+        """grab_next_visits should retrieve tasks without last update (nor visit stats)"""
         visit_type = next(iter(listed_origins_by_type))
 
         origins = []
@@ -1087,7 +1127,9 @@ class TestScheduler:
 
         # Grab some new visits
         next_visits = swh_scheduler.grab_next_visits(
-            visit_type, count=len(origins), policy="origins_without_last_update",
+            visit_type,
+            count=len(origins),
+            policy="origins_without_last_update",
         )
         # we do have the one without any last update
         assert len(next_visits) == len(origins)
@@ -1163,7 +1205,9 @@ class TestScheduler:
 
         # Grab next visits
         actual_visits = swh_scheduler.grab_next_visits(
-            visit_type, count=len(origins), policy="origins_without_last_update",
+            visit_type,
+            count=len(origins),
+            policy="origins_without_last_update",
         )
         assert len(actual_visits) == len(origins)
 
@@ -1266,7 +1310,10 @@ class TestScheduler:
 
         new_visit_date = utcnow()
         visit_stats = OriginVisitStats(
-            url=url, visit_type="git", last_successful=None, last_visit=new_visit_date,
+            url=url,
+            visit_type="git",
+            last_successful=None,
+            last_visit=new_visit_date,
         )
         swh_scheduler.origin_visit_stats_upsert([visit_stats])
 
@@ -1321,9 +1368,7 @@ class TestScheduler:
             assert visit_stat is not None
 
     def test_origin_visit_stats_upsert_cardinality_failing(self, swh_scheduler) -> None:
-        """Batch upsert does not support altering multiple times the same origin-visit-status
-
-        """
+        """Batch upsert does not support altering multiple times the same origin-visit-status"""
         with pytest.raises(SchedulerException, match="CardinalityViolation"):
             swh_scheduler.origin_visit_stats_upsert(
                 [
